@@ -31,12 +31,13 @@
 
 #include <config.h>
 
-#include "libgtop-i18n.h"
+#include <glib/gi18n-lib.h>
 #include <glibtop.h>
 #include <glibtop/open.h>
 #include <glibtop/close.h>
 #include <glibtop/command.h>
 
+#include <glib/gstrfuncs.h>
 
 #include <glibtop/parameter.h>
 
@@ -65,8 +66,6 @@ char *program_invocation_short_name;
 char *program_invocation_name;
 #endif
 
-void handle_parent_connection (int s);
-void handle_slave_connection (int input, int output);
 
 #if !defined(INTERNET_DOMAIN_SOCKETS)
 #error "Internet Domain sockets are required"
@@ -87,7 +86,7 @@ static int invoked_from_inetd = 0;
 static int changed_uid = 0;
 
 void
-syslog_message (int priority, char *format, ...)
+syslog_message (int priority, const char *format, ...)
 {
     va_list ap;
     char buffer [BUFSIZ];
@@ -100,7 +99,7 @@ syslog_message (int priority, char *format, ...)
 }
 
 void
-syslog_io_message (int priority, char *format, ...)
+syslog_io_message (int priority, const char *format, ...)
 {
     va_list ap;
     char buffer [BUFSIZ];
@@ -110,7 +109,7 @@ syslog_io_message (int priority, char *format, ...)
     vsnprintf (buffer, BUFSIZ-1, format, ap);
     va_end (ap);
 
-    snprintf (buffer2, BUFSIZ-1, "%s: %s", buffer, strerror (errno));
+    snprintf (buffer2, BUFSIZ-1, "%s: %s", buffer, g_strerror (errno));
     syslog (priority, "%s", buffer2);
 }
 
@@ -274,7 +273,12 @@ permitted (u_long host_addr, int fd)
 static int
 setup_table (void)
 {
-    char hostname [HOSTNAMSZ], screen [BUFSIZ];
+    char hostname [HOSTNAMSZ];
+
+#ifdef AUTH_MAGIC_COOKIE
+    char screen [BUFSIZ];
+#endif
+
     long host_addr;
     int i, hosts = 0;
 
@@ -460,7 +464,7 @@ const struct poptOption popt_options [] = {
       N_("Don't fork into background"), N_("NO-DAEMON") },
     { "inetd", 'i', POPT_ARG_NONE, &invoked_from_inetd, 0,
       N_("Invoked from inetd"), N_("INETD") },
-    { NULL, '\0', 0, NULL, 0 }
+    { NULL, '\0', 0, NULL, 0, NULL, NULL }
 };
 
 int
